### CoreML and ONNX models
MediaPipe models ([MediaPipe BlazeFace Short Range](https://drive.google.com/file/d/1d4-xJP9PVzOvMBDgIjz6NhvpnlG9_i0S/preview), [MediaPipe BlazeFace Full Range](https://drive.google.com/file/d/1jpQt8TB1nMFQ49VSSBKdNEdQOygNRvCP/preview)), and [MediaPipe Face Landmark](https://github.com/google-ai-edge/mediapipe/blob/master/docs/solutions/face_mesh.md#face-landmark-model)) are ported to CoreML and ONNX. Certain pre and post processing steps are different from original implementation.
### LICENSE (Apache License 2.0)
All the models are licensed under the same terms as [MediaPipe](https://github.com/google-ai-edge/mediapipe/blob/master/LICENSE).
